@@ -23,18 +23,11 @@ import testtools
 import mock
 from oslo_concurrency import processutils
 from oslotest import base as test_base
-import six
 
 from ironic_python_agent import errors
 from ironic_python_agent import utils
 
 
-if six.PY2:
-    OPEN_FUNCTION_NAME = '__builtin__.open'
-else:
-    OPEN_FUNCTION_NAME = 'builtins.open'
-
-
 class ExecuteTestCase(testtools.TestCase):
     """This class is a copy of the same class in openstack/ironic."""
 
@@ -135,13 +128,13 @@ grep foo
 class GetAgentParamsTestCase(test_base.BaseTestCase):
 
     @mock.patch('oslo_log.log.getLogger')
-    @mock.patch(OPEN_FUNCTION_NAME)
+    @mock.patch('six.moves.builtins.open')
     def test__read_params_from_file_fail(self, logger_mock, open_mock):
         open_mock.side_effect = Exception
         params = utils._read_params_from_file('file-path')
-        self.assertEqual(params, {})
+        self.assertEqual({}, params)
 
-    @mock.patch(OPEN_FUNCTION_NAME)
+    @mock.patch('six.moves.builtins.open')
     def test__read_params_from_file(self, open_mock):
         kernel_line = 'api-url=http://localhost:9999 baz foo=bar\n'
         open_mock.return_value.__enter__ = lambda s: s
@@ -151,8 +144,8 @@ class GetAgentParamsTestCase(test_base.BaseTestCase):
         params = utils._read_params_from_file('file-path')
         open_mock.assert_called_once_with('file-path')
         read_mock.assert_called_once_with()
-        self.assertEqual(params['api-url'], 'http://localhost:9999')
-        self.assertEqual(params['foo'], 'bar')
+        self.assertEqual('http://localhost:9999', params['api-url'])
+        self.assertEqual('bar', params['foo'])
         self.assertFalse('baz' in params)
 
     @mock.patch.object(utils, '_set_cached_params')
@@ -201,7 +194,7 @@ class GetAgentParamsTestCase(test_base.BaseTestCase):
         self.assertEqual(expected_params, returned_params)
         self.assertEqual(0, set_cache_mock.call_count)
 
-    @mock.patch(OPEN_FUNCTION_NAME)
+    @mock.patch('six.moves.builtins.open')
     @mock.patch.object(glob, 'glob')
     def test__get_vmedia_device(self, glob_mock, open_mock):
 
@@ -223,15 +216,15 @@ class GetAgentParamsTestCase(test_base.BaseTestCase):
     @mock.patch.object(os.path, 'exists')
     @mock.patch.object(os, 'mkdir')
     @mock.patch.object(utils, 'execute')
-    def test__get_vmedia_params_by_label(self, execute_mock, mkdir_mock,
-                                         exists_mock, read_params_mock,
-                                         mkdtemp_mock, rmtree_mock):
+    def test__get_vmedia_params_by_label_lower_case(
+            self, execute_mock, mkdir_mock, exists_mock, read_params_mock,
+            mkdtemp_mock, rmtree_mock):
         mkdtemp_mock.return_value = "/tempdir"
 
         null_output = ["", ""]
         expected_params = {'a': 'b'}
         read_params_mock.return_value = expected_params
-        exists_mock.return_value = True
+        exists_mock.side_effect = [True, False]
         execute_mock.side_effect = [null_output, null_output]
 
         returned_params = utils._get_vmedia_params()
@@ -245,6 +238,36 @@ class GetAgentParamsTestCase(test_base.BaseTestCase):
         mkdtemp_mock.assert_called_once_with()
         rmtree_mock.assert_called_once_with("/tempdir")
 
+    @mock.patch.object(shutil, 'rmtree', autospec=True)
+    @mock.patch.object(tempfile, 'mkdtemp', autospec=True)
+    @mock.patch.object(utils, '_read_params_from_file')
+    @mock.patch.object(os.path, 'exists')
+    @mock.patch.object(os, 'mkdir')
+    @mock.patch.object(utils, 'execute')
+    def test__get_vmedia_params_by_label_upper_case(
+            self, execute_mock, mkdir_mock, exists_mock, read_params_mock,
+            mkdtemp_mock, rmtree_mock):
+        mkdtemp_mock.return_value = "/tempdir"
+
+        null_output = ["", ""]
+        expected_params = {'a': 'b'}
+        read_params_mock.return_value = expected_params
+        exists_mock.side_effect = [False, True]
+        execute_mock.side_effect = [null_output, null_output]
+
+        returned_params = utils._get_vmedia_params()
+
+        execute_mock.assert_any_call('mount', "/dev/disk/by-label/IR-VFD-DEV",
+                                     "/tempdir")
+        read_params_mock.assert_called_once_with("/tempdir/parameters.txt")
+        exists_mock.assert_has_calls(
+            [mock.call("/dev/disk/by-label/ir-vfd-dev"),
+             mock.call("/dev/disk/by-label/IR-VFD-DEV")])
+        execute_mock.assert_any_call('umount', "/tempdir")
+        self.assertEqual(expected_params, returned_params)
+        mkdtemp_mock.assert_called_once_with()
+        rmtree_mock.assert_called_once_with("/tempdir")
+
     @mock.patch.object(shutil, 'rmtree', autospec=True)
     @mock.patch.object(tempfile, 'mkdtemp', autospec=True)
     @mock.patch.object(utils, '_get_vmedia_device')
@@ -261,12 +284,15 @@ class GetAgentParamsTestCase(test_base.BaseTestCase):
         null_output = ["", ""]
         expected_params = {'a': 'b'}
         read_params_mock.return_value = expected_params
-        exists_mock.return_value = False
+        exists_mock.side_effect = [False, False]
         execute_mock.side_effect = [null_output, null_output]
         get_device_mock.return_value = "sda"
 
         returned_params = utils._get_vmedia_params()
 
+        exists_mock.assert_has_calls(
+            [mock.call("/dev/disk/by-label/ir-vfd-dev"),
+             mock.call("/dev/disk/by-label/IR-VFD-DEV")])
         execute_mock.assert_any_call('mount', "/dev/sda",
                                      "/tempdir")
         read_params_mock.assert_called_once_with("/tempdir/parameters.txt")
